@@ -27,7 +27,7 @@ sub GetLastError
 #==============================================================================
 sub context
 {
-  Apache2::ASP::HTTPContext->current;
+  $Apache2::ASP::HTTPContext::ClassName->current;
 }# end context()
 
 
